Lambdas
This service provides a set of utilities required by the Catalyst Server Clients\Consumers in order to retrieve or validate data.
Retrieve detailed information about the services
Catalyst services information
GET /lambdas/status HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
Catalyst services information
{
"version": "1.0",
"currentTime": 1628875330839,
"contentServerUrl": "https://peer.decentraland.org/content/",
"commitHash": "7890de4598f88a382863ea5f399b9cc17b80b42e",
"catalystVersion": "1.3.3"
}Retrieve the list of collections URNs
Array of collections URNs and names
Internal Server Error
GET /lambdas/collections HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
{
"collections": [
{
"id": "urn:decentraland:off-chain:base-avatars",
"name": "Base Wearables"
},
{
"id": "urn:decentraland:ethereum:collections-v1:3lau_basics",
"name": "dcl://3lau_basics"
},
{
"id": "urn:decentraland:ethereum:collections-v1:atari_launch",
"name": "dcl://atari_launch"
},
{
"id": "urn:decentraland:ethereum:collections-v1:binance_us_collection",
"name": "dcl://binance_us_collection"
},
{
"id": "urn:decentraland:ethereum:collections-v1:china_flying",
"name": "dcl://china_flying"
},
{
"id": "urn:decentraland:ethereum:collections-v1:community_contest",
"name": "dcl://community_contest"
},
{
"id": "urn:decentraland:ethereum:collections-v1:cybermike_cybersoldier_set",
"name": "dcl://cybermike_cybersoldier_set"
},
{
"id": "urn:decentraland:ethereum:collections-v1:cz_mercenary_mtz",
"name": "dcl://cz_mercenary_mtz"
}
]
}Downloads a thumbnail image for the specified urn
Uniform Resource Name (URN) that identifies the asset
urn:decentraland:matic:collections-v2:0x04e43281f36e1f1bfae6f38bc276cb48fb8ac632:0Thumbnail image
binaryGET /lambdas/collections/contents/{urn}/thumbnail HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
Thumbnail image
binaryDownloads the image for the specified urn
Uniform Resource Name (URN) that identifies the asset
urn:decentraland:matic:collections-v2:0x04e43281f36e1f1bfae6f38bc276cb48fb8ac632:0Resource image
binaryGET /lambdas/collections/contents/{urn}/image HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
Resource image
binaryRetrieve ERC721/NFT Entity details
Ethereum chain ID: ETHEREUM_MAINNET = 1 ETHEREUM_RINKEBY = 4 ETHEREUM_GOERLI = 5 ETHEREUM_KOVAN = 42 MATIC_MAINNET = 137 MATIC_MUMBAI = 80001
137Hash of the Contract. This will be used to build the URN that identifies the NFT.
0x123db7844eaf7da11d88cf1754945bbd020742efToken Identifier
3Optional rarity description that will be return as part of the NFT description common: 100000 uncommon: 10000 rare: 5000 epic: 1000 legendary: 100 mythic: 10 unique: 1
legendaryResource image
Bad Request: invalid chain ID
Entity Not Found
Internal Server Error
GET /lambdas/collections/standard/erc721/{chainId}/{contract}/{option}/{emission} HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
{
"id": "urn:decentraland:matic:collections-v2:0x123db7844eaf7da11d88cf1754945bbd020742ef:3",
"name": "4Skin Libre Upper Body",
"description": "DCL Wearable {emission}/100",
"language": "en-US",
"image": "https://peer.decentraland.org/content/contents/Qmbcs6tGSYtikJB3d5QEWP3uKD9XXnrUfsrYDzL3kVaAee",
"thumbnail": "https://peer.decentraland.org/content/contents/QmW1JmHYXZLRqpzTMmA6MZKi6AFNeYpWRGTqr7pgoyeG11",
"attributes": [
{
"trait_type": "Rarity",
"value": "legendary"
},
{
"trait_type": "Category",
"value": "upper_body"
},
{
"trait_type": "Body Shape",
"value": "BaseMale"
},
{
"trait_type": "Body Shape",
"value": "BaseFemale"
}
]
}Get a list of wearables owned by the given address
Ethereum address from which you want to get the list of wearables
0xa87d168717538e86d71ac48baccaeb84162de602If present, response will be extended with the entity data.
trueIf present, response will include the third-party wearables owned by the address. They will appear before other wearables if the response is paginated.
trueThe number of the requested page.
1The size of the requested page.
10Determines the field to be sort by. By default it will be by transferredAt. Possible values: transferredAt and rarity.
rarityList of wearables owned by the given address
Failed to fetch wearables
GET /lambdas/users/{address}/wearables HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
{
"elements": [
{
"urn": "urn:decentraland:matic:collections-v2:0x6d83706836e820e79252edd48da419d2d03592d4:0",
"individualData": [
{
"id": "0x6d83706836e820e79252edd48da419d2d03592d4-6407",
"tokenId": "6407",
"transferredAt": "1662738697",
"price": "10000000000000000000000000"
},
{
"id": "0x6d83706836e820e79252edd48da419d2d03592d4-5452",
"tokenId": "5452",
"transferredAt": "1662738325",
"price": "10000000000000000000000000"
},
{
"id": "0x6d83706836e820e79252edd48da419d2d03592d4-4497",
"tokenId": "4497",
"transferredAt": "1662737945",
"price": "10000000000000000000000000"
},
{
"id": "0x6d83706836e820e79252edd48da419d2d03592d4-3542",
"tokenId": "3542",
"transferredAt": "1662737595",
"price": "10000000000000000000000000"
},
{
"id": "0x6d83706836e820e79252edd48da419d2d03592d4-2587",
"tokenId": "2587",
"transferredAt": "1662737239",
"price": "10000000000000000000000000"
},
{
"id": "0x6d83706836e820e79252edd48da419d2d03592d4-1632",
"tokenId": "1632",
"transferredAt": "1662736881",
"price": "10000000000000000000000000"
},
{
"id": "0x6d83706836e820e79252edd48da419d2d03592d4-677",
"tokenId": "677",
"transferredAt": "1662736515",
"price": "10000000000000000000000000"
}
],
"amount": 7
},
{
"urn": "urn:decentraland:matic:collections-v2:0x475abb52a7e925209b1334e52bfb62e1da9ebf62:1",
"individualData": [
{
"id": "0x475abb52a7e925209b1334e52bfb62e1da9ebf62-105312291668557186697918027683670432318895095400549111254310977681",
"tokenId": "105312291668557186697918027683670432318895095400549111254310977681",
"transferredAt": "1662040489",
"price": "1000000000000000000"
}
],
"amount": 1
},
{
"urn": "urn:decentraland:matic:collections-v2:0x710dce41dceace2f0e06c0cffee25fe65ad6f64c:0",
"individualData": [
{
"id": "0x710dce41dceace2f0e06c0cffee25fe65ad6f64c-339",
"tokenId": "339",
"transferredAt": "1662040423",
"price": "500000000000000000"
}
],
"amount": 1
},
{
"urn": "urn:decentraland:matic:collections-v2:0x293d1ae40b28c39d7b013d4a1fe3c5a8c016bf19:1",
"individualData": [
{
"id": "0x293d1ae40b28c39d7b013d4a1fe3c5a8c016bf19-105312291668557186697918027683670432318895095400549111254310977722",
"tokenId": "105312291668557186697918027683670432318895095400549111254310977722",
"transferredAt": "1662040329",
"price": "100000000000000000"
}
],
"amount": 1
}
],
"totalAmount": 23,
"pageNum": "2",
"pageSize": "4"
}Get a list of emotes owned by the given address
Ethereum address from which you want to get the list of emotes
0xf4f7512c68f358856514cd4e449fc6c5ac04bb15Third Party collection Id to filter emotes, if this param is not sent then the 3rd parties emotes are not shown. If it is sent, only the 3rd parties emotes are shown.
urn:decentraland:matic:collections-thirdparty:ntr1-meta:ntr1-meta-1ef79e7bIf present, response will be extended with the entity data.
trueThe number of the requested page.
1The size of the requested page
10List of emotes owned by the given address
Failed to fetch emotes for the address
GET /lambdas/users/{address}/emotes HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
{
"elements": [
{
"urn": "urn:decentraland:matic:collections-v2:0xa5b27856547a7d7c238b0e6c2de7a73556b915ba:0",
"amount": 1
},
{
"urn": "urn:decentraland:matic:collections-v2:0x7f26599ad1e9ad0ce6d47c5043d70d3bcd3d259a:0",
"amount": 1
},
{
"urn": "urn:decentraland:matic:collections-v2:0xeed6bdbdec460e258688e15816e8a9f760c3651a:0",
"amount": 1
},
{
"urn": "urn:decentraland:matic:collections-v2:0xa6c722476bdd17bf2adb65e96388345d83259f3b:0",
"amount": 1
}
],
"totalAmount": 973,
"pageNum": "3",
"pageSize": "4"
}Get a list of names owned by the given address
Ethereum address from which you want to get the list of names
0xddf1eec586d8f8f0eb8c5a3bf51fb99379a55684The number of the requested page. It needs pageSize to be present to enable a paginated response.
1The size of the requested page. It needs pageNum to be present to enable a paginated response.
10List of names owned by the given address
Failed to fetch names for the address
GET /lambdas/users/{address}/names HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
{
"names": [
{
"name": "Gojo",
"contractAddress": "0x2a187453064356c898cae034eaed119e1663acb8",
"tokenId": "115307283102801270656452808194409685445355100338904720773052040552422075323100",
"price": "25000000000000000000000"
},
{
"name": "Ugh",
"contractAddress": "0x2a187453064356c898cae034eaed119e1663acb8",
"tokenId": "109851145768931514038649521124955142005672037705020471158837454870244371101640",
"price": "20000000000000000000000"
},
{
"name": "Pain",
"contractAddress": "0x2a187453064356c898cae034eaed119e1663acb8",
"tokenId": "37860252415586502442474289153833538639704044038329376660459632788847982021683",
"price": "35000000000000000000000"
},
{
"name": "Hawks",
"contractAddress": "0x2a187453064356c898cae034eaed119e1663acb8",
"tokenId": "61045570331711729163571591712822027676157304898474053802260900686360273563216",
"price": "30000000000000000000000"
}
],
"totalAmount": 812,
"pageNum": "2",
"pageSize": "4"
}Get a list of lands owned by the given address
Ethereum address from which you want to get the list of lands
0xddf1eec586d8f8f0eb8c5a3bf51fb99379a55684The number of the requested page. It needs pageSize to be present to enable a paginated response.
1The size of the requested page. It needs pageNum to be present to enable a paginated response.
10List of lands owned by the given address
Failed to fetch lands for the address
GET /lambdas/users/{address}/lands HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
{
"lands": [
{
"name": "No rules red light",
"contractAddress": "0x959e104e1a4db6317fa58f8295f586e1a978c297",
"tokenId": "2178",
"category": "estate",
"description": "No rules red light",
"price": "13850000000000000000000",
"image": "https://api.decentraland.org/v1/estates/2178/map.png"
},
{
"name": null,
"contractAddress": "0xf87e31492faf9a91b02ee0deaad50d51d56d5d4d",
"tokenId": "115792089237316195423570985008687907830471066081937686987411485309984659472358",
"category": "parcel",
"x": "-68",
"y": "-26",
"price": null,
"image": "https://api.decentraland.org/v1/parcels/-68/-26/map.png"
}
],
"totalAmount": 692,
"pageNum": "1",
"pageSize": "2"
}Get the permissions a user has for a parcel
Ethereum address from which you want to get the permissions
0xddf1eec586d8f8f0eb8c5a3bf51fb99379a55684X coordinate of the parcel
100Y coordinate of the parcel
100permissions a user has for a parcel
Bad request
GET /lambdas/users/{address}/parcels/{x}/{y}/permissions HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
{
"address": true,
"operator": false,
"updateOperator": false,
"updateManager": false,
"approvedForAll": false
}Returns the list of third party wearables for the provided address
Returns the list of third party wearables for the provided address
Ethereum address from which you want to get the list of wearables
0xf4f7512c68f358856514cd4e449fc6c5ac04bb15The number of the requested page.
1The size of the requested page.
10Returns the list of third party wearables
GET /lambdas/users/{address}/third-party-wearables HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
Returns the list of third party wearables
{
"elements": [
{
"urn": "text",
"amount": 1,
"name": "text",
"category": "text",
"entity": {
"version": "text",
"id": "text",
"type": "text",
"timestamp": 1,
"pointers": [
"text"
],
"content": [
{
"file": "text",
"hash": "text"
}
],
"metadata": {}
},
"individualData": [
{
"id": "text"
}
]
}
],
"totalAmount": 1,
"pageNum": 1,
"pageSize": 1
}Returns the list of third party wearables for the given collection
Returns the list of third party wearables for the given collection
Ethereum address from which you want to get the list of wearables
0xf4f7512c68f358856514cd4e449fc6c5ac04bb15Third Party collection Id to filter wearables.
urn:decentraland:matic:collections-thirdparty:ntr1-meta:ntr1-meta-1ef79e7bThe number of the requested page.
1The size of the requested page.
10Returns the list of third party wearables
GET /lambdas/users/{address}/third-party-wearables/{collectionId} HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
Returns the list of third party wearables
{
"elements": [
{
"urn": "text",
"amount": 1,
"name": "text",
"category": "text",
"entity": {
"version": "text",
"id": "text",
"type": "text",
"timestamp": 1,
"pointers": [
"text"
],
"content": [
{
"file": "text",
"hash": "text"
}
],
"metadata": {}
},
"individualData": [
{
"id": "text"
}
]
}
],
"totalAmount": 1,
"pageNum": 1,
"pageSize": 1
}Search for wearables based on the applied filters and retrieve detailed information
Lis of URNs that identify the collection. Maximum amount of ids allowed is 500.
urn:decentraland:ethereum:collections-v1:mf_sammichgamerList of wearables URNs to search. Maximum amount of ids allowed is 500.
urn:decentraland:ethereum:collections-v1:binance_us_collection:binance_us_hatSearch text
HoodieLimit the quantity of results that will be returned by the request. You can only request up to 500 results.
2The result will always be ordered by the local timestamp fields but in case of timestamp collisions, you can use the lastId field to filter the result
urn:decentraland:ethereum:collections-v1:binance_us_collection:binance_us_hatCatalyst services health information
Bad Request
GET /lambdas/collections/wearables HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
{
"wearables": [
{
"id": "urn:decentraland:ethereum:collections-v1:binance_us_collection:binance_us_hat",
"description": "Binance US Hat",
"image": "https://peer.decentraland.org/content/contents/QmP6kMEf1yTUfNVYPXGTyErBH3Ao3CHHwcUBcqkMaAGspk",
"thumbnail": "https://peer.decentraland.org/content/contents/QmcDJvsm6muyZyeAN9S3znX2HHzuybyscDxCh4pBoJ4axh",
"collectionAddress": "0xa8ee490e4c4da48cc1653502c1a77479d4d818de",
"rarity": "uncommon",
"data": {
"replaces": [
"helmet"
],
"hides": [
"hair"
],
"tags": [
"binance",
"us",
"hat",
"decentraland",
"exclusive"
],
"category": "hat",
"representations": [
{
"bodyShapes": [
"urn:decentraland:off-chain:base-avatars:BaseMale"
],
"mainFile": "M_BinanceUS_Hat.glb",
"overrideReplaces": [],
"overrideHides": [],
"contents": [
{
"key": "AvatarWearables_TX_2.png",
"url": "https://peer.decentraland.org/content/contents/QmYktkLr5rnn9zPPARkavhVowvTNTih8uWq8BVscTGxtZD"
},
{
"key": "F_BinanceUS_Hat.glb",
"url": "https://peer.decentraland.org/content/contents/QmQ1cK2KDyPYz4nF1j7kZPqztJmPkSiMP7dfSJP1cw8FPt"
},
{
"key": "M_BinanceUS_Hat.glb",
"url": "https://peer.decentraland.org/content/contents/QmSM2L7vRbPPqVBy97pdxHPTr83EnWAywekg4Pd4HAATvv"
},
{
"key": "binance_hoddie.png",
"url": "https://peer.decentraland.org/content/contents/QmcbRo8J4fkSuPjocgKEqyKZnkgqjZSVVd3URpmNkikfnc"
}
]
},
{
"bodyShapes": [
"urn:decentraland:off-chain:base-avatars:BaseFemale"
],
"mainFile": "F_BinanceUS_Hat.glb",
"overrideReplaces": [],
"overrideHides": [],
"contents": [
{
"key": "AvatarWearables_TX_2.png",
"url": "https://peer.decentraland.org/content/contents/QmYktkLr5rnn9zPPARkavhVowvTNTih8uWq8BVscTGxtZD"
},
{
"key": "F_BinanceUS_Hat.glb",
"url": "https://peer.decentraland.org/content/contents/QmQ1cK2KDyPYz4nF1j7kZPqztJmPkSiMP7dfSJP1cw8FPt"
},
{
"key": "M_BinanceUS_Hat.glb",
"url": "https://peer.decentraland.org/content/contents/QmSM2L7vRbPPqVBy97pdxHPTr83EnWAywekg4Pd4HAATvv"
},
{
"key": "binance_hoddie.png",
"url": "https://peer.decentraland.org/content/contents/QmcbRo8J4fkSuPjocgKEqyKZnkgqjZSVVd3URpmNkikfnc"
}
]
}
]
},
"i18n": [
{
"code": "en",
"text": "Binance US Hat"
},
{
"code": "es",
"text": "Gorra de Binance US"
}
],
"createdAt": 1617888339603,
"updatedAt": 1617888339603
},
{
"id": "urn:decentraland:ethereum:collections-v1:community_contest:cw_bell_attendant_hat",
"description": "",
"image": "https://peer.decentraland.org/content/contents/QmfDGLvXyoD43iB2euMwqtxaRKKA1Y39BbmmpenCWKjw2n",
"thumbnail": "https://peer.decentraland.org/content/contents/Qmbs4UgxEhHwD8umiW3VWta8NBQy7mmBhxNgBRuNuE7pvw",
"collectionAddress": "0x32b7495895264ac9d0b12d32afd435453458b1c6",
"rarity": "legendary",
"data": {
"replaces": [
"helmet",
"tiara",
"top_head"
],
"hides": [
"hair"
],
"tags": [
"hat",
"exclusive",
"launch",
"20.02.20",
"decentraland",
"community",
"wearables",
"exclusive"
],
"category": "hat",
"representations": [
{
"bodyShapes": [
"urn:decentraland:off-chain:base-avatars:BaseMale"
],
"mainFile": "M_Hat_BellAttendant.glb",
"overrideReplaces": [],
"overrideHides": [],
"contents": [
{
"key": "AvatarWearables_Emissive_TX.png",
"url": "https://peer.decentraland.org/content/contents/QmUrULH5u6RB6BjX9MQD97oi8djrvGvgqvNXq5ULXceZ6j"
},
{
"key": "AvatarWearables_TX.png",
"url": "https://peer.decentraland.org/content/contents/QmXGZq67BhmGm8WpmXrSL8EqotM4nEs3CcP8e8fZE9dgWS"
},
{
"key": "AvatarWearables_TX_2.png",
"url": "https://peer.decentraland.org/content/contents/QmYktkLr5rnn9zPPARkavhVowvTNTih8uWq8BVscTGxtZD"
},
{
"key": "F_Hat_BellAttendant.glb",
"url": "https://peer.decentraland.org/content/contents/QmYJ8pS3hcF5RUu2G4F4gtrTaJEP6ZpKjPqUWfvAa3CBw8"
},
{
"key": "M_Hat_BellAttendant.glb",
"url": "https://peer.decentraland.org/content/contents/QmTw9sRvB5WhbLwrvk8QGMJbTqhXsrucds64Qfgs6HYaHu"
}
]
},
{
"bodyShapes": [
"urn:decentraland:off-chain:base-avatars:BaseFemale"
],
"mainFile": "F_Hat_BellAttendant.glb",
"overrideReplaces": [],
"overrideHides": [],
"contents": [
{
"key": "AvatarWearables_Emissive_TX.png",
"url": "https://peer.decentraland.org/content/contents/QmUrULH5u6RB6BjX9MQD97oi8djrvGvgqvNXq5ULXceZ6j"
},
{
"key": "AvatarWearables_TX.png",
"url": "https://peer.decentraland.org/content/contents/QmXGZq67BhmGm8WpmXrSL8EqotM4nEs3CcP8e8fZE9dgWS"
},
{
"key": "AvatarWearables_TX_2.png",
"url": "https://peer.decentraland.org/content/contents/QmYktkLr5rnn9zPPARkavhVowvTNTih8uWq8BVscTGxtZD"
},
{
"key": "F_Hat_BellAttendant.glb",
"url": "https://peer.decentraland.org/content/contents/QmYJ8pS3hcF5RUu2G4F4gtrTaJEP6ZpKjPqUWfvAa3CBw8"
},
{
"key": "M_Hat_BellAttendant.glb",
"url": "https://peer.decentraland.org/content/contents/QmTw9sRvB5WhbLwrvk8QGMJbTqhXsrucds64Qfgs6HYaHu"
}
]
}
]
},
"i18n": [
{
"code": "en",
"text": "Bell Attendant Hat"
},
{
"code": "es",
"text": "Sombrero de Botones"
}
],
"createdAt": 1618845343458,
"updatedAt": 1618845343458
}
],
"filters": {
"textSearch": "hat"
},
"pagination": {
"limit": 2,
"next": "?textSearch=hat&lastId=urn%3Adecentraland%3Aethereum%3Acollections-v1%3Acommunity_contest%3Acw_bell_attendant_hat&limit=2"
}
}Retrieve the list of Catalyst Servers
List of Catalyst Servers
GET /lambdas/contracts/servers HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
List of Catalyst Servers
[
{
"baseUrl": "https://interconnected.online",
"owner": "0x75e1d32289679dfcB2F01fBc0e043B3d7F9Cd443",
"id": "0xa88ccc81441dd364f33f0db770508d63e6ce933e2a2f24039974c887e535e2cd"
},
{
"baseUrl": "https://peer.decentraland.org",
"owner": "0xFE95E04A628087FCdD5f278E61F148B47471Af4A",
"id": "0xfb539741ce2cc5e843a1690c57d9a67a3a193f52df217b589b131e90b1130db0"
},
{
"baseUrl": "https://peer.melonwave.com",
"owner": "0x6327Ef6bAE918584B86AcfD58bDEB6EF9211e371",
"id": "0xdc79f86d81f8be2e8ecf51f5be7df04edca3c815846f890c8b1bcade6bcf2a6c"
},
{
"baseUrl": "https://peer.kyllian.me",
"owner": "0xF78Dfd2a940c1c204d9eb5D1fF7988b7AEC3F01a",
"id": "0x77fa03b44621846a18358ca6e766a5fa6959a1b25ae2229f16be328dac8931df"
},
{
"baseUrl": "https://peer.decentral.games",
"owner": "0xa7C825BB8c2C4d18288af8efe38c8Bf75A1AAB51",
"id": "0x397114b887b57bb13bd50e35a31cf7b91aa62117a040cc029e4935749f595d26"
},
{
"baseUrl": "https://peer.uadevops.com",
"owner": "0x3f95F857F89357fb1592C74dEd1f4556c6272edB",
"id": "0x242d013bc99da6593970d01f044f46194eee33b8947384efbafc10ae1a7917fc"
},
{
"baseUrl": "https://peer.dclnodes.io",
"owner": "0x3d7C732f54f7D60d14eabca8A7Da3097cEc3AF1e",
"id": "0xd5d98a65db8d09437f138b06d112a630c762cca7082c96fa0dcd4102abfc0aef"
},
{
"baseUrl": "https://peer-eu1.decentraland.org",
"owner": "0xEfc549434A03756F6e37A43757a2927605D8839B",
"id": "0x4e55ad26203dfef9b2235dfea39d531b2b64814e606c0294768c0d1469124479"
},
{
"baseUrl": "https://peer-ec1.decentraland.org",
"owner": "0xe5d0c3fEA1e5F01CA4098e9580B93B3b5d0Ea768",
"id": "0x63edaad1a9bdfa5a492b12d4920655c5812c8572d1cdeca2f3f5e8cc49efc593"
},
{
"baseUrl": "https://peer-wc1.decentraland.org",
"owner": "0x4eAC6325e1DBF1Ac90434d39766e164Dca71139E",
"id": "0xca6c9aff525af8ae6fb73c59c402619030323150b0dfcb39574c9eed608e7309"
},
{
"baseUrl": "https://peer-ap1.decentraland.org",
"owner": "0xF1598bC1aD6474d6e884684706ABdd1e3468D199",
"id": "0x201a63dfe16e0e870f83367ac0ce1dd90b6e851f78baae140c81741e3f5fc9ec"
}
]Retrieve the Point of Interest list of coordinates
List of Point of Interest coordinates. These are currently highlighted in the DCL Atlas.
GET /lambdas/contracts/pois HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
List of Point of Interest coordinates. These are currently highlighted in the DCL Atlas.
[
"-29,55",
"-108,-30",
"144,-34",
"-10,58",
"-79,-54",
"111,-23",
"25,74",
"26,9",
"-143,-125",
"-25,25",
"-119,133",
"-48,-110",
"23,-123",
"38,103",
"82,-149",
"52,83",
"10,52",
"19,-120",
"-67,-114",
"22,-118",
"46,-52",
"-96,110",
"-108,129",
"-119,125",
"96,-30",
"-1,-135",
"-23,69",
"-116,-49",
"95,-7"
]Retrieve list of forbidden user names. The prohibition of these names is decided through the DAO and need to be voted, the list lives in a Smart Contract and the Catalyst just consumes this information to present it to the client. In order to add a new name a new proposal needs to be created, approved and a transaction should be sent by a DAO committee member.
Array of forbidden names by the DAO
GET /lambdas/contracts/denylisted-names HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
Array of forbidden names by the DAO
[
"OffensiveName1",
"OffensiveName2",
"OffensiveName3"
]Given a signed message and it's AuthChain, validate it's authenticity. A message can be signed, for example, to prove ownership of the Entity pointers that they want to modify.
Result of the signature validation with owner address or errors
Bad Request: Expected 'signedMessage' property to be set
POST /lambdas/crypto/validate-signature HTTP/1.1
Host: peer.decentraland.zone
Content-Type: application/json; charset=utf-8
Accept: */*
Content-Length: 724
{
"timestamp": "1629753096906",
"signedMessage": "QmfSjDEi2a43aURjbNR3KTXmBB3wWfkJb6Vdmu3vmaNW5H",
"authChain": [
{
"type": "SIGNER",
"payload": "0x716954738e57686a08902d9dd586e813490fee23"
},
{
"type": "ECDSA_EPHEMERAL",
"payload": "Decentraland Login\nEphemeral address: 0x90a43461d3e970785B945FFe8f7628F2BC962D6a\nExpiration: 2021-07-10T20:55:42.215Z",
"signature": "0xe64e46fdd7d8789c0debec54422ae77e31b77e5a28287e072998e1114e252c57328c17756400d321e9e77032347c9d05e63fb59a3b6c3ab754565f9db86b8c481b"
},
{
"type": "ECDSA_SIGNED_ENTITY",
"payload": "QmNMZBy7khBxdigikA8mcJMyv6yeBXfMv3iAcUiBr6n72C",
"signature": "0xbed22719dcdc19580353108027c41c65863404879592c65014d806efa961c629777adc76986193eaee4e48f278ec59feb1c289827254230af85b2955157ec8061b"
}
]
}{
"valid": true,
"ownerAddress": "0xa8ee490e4c4da48cc1653502c1a77479d4d818de"
}Returns the list of scenes where there are more users with coordinates and the list of parcels that compose the scene.
List of scenes
GET /lambdas/explore/hot-scenes HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
List of scenes
[
{
"id": "QmT2pZZ5XX5LZ8KTy9ExRnBEcMZzcChfnAXyBafyRp4sdY",
"name": "WonderMine Crafting Game",
"baseCoords": [
-29,
55
],
"usersTotalCount": 107,
"parcels": [
[
-29,
55
],
[
-29,
56
]
],
"thumbnail": "https://wonderzone.io/img/scenes/wondermine_thumb2.jpg",
"creator": "WonderZone",
"description": "Mine meteors, get loot, and craft wearables!",
"realms": [
{
"serverName": "loki",
"url": "https://interconnected.online",
"layer": "amber",
"usersCount": 45,
"maxUsers": 100,
"userParcels": [
[
-27,
57
],
[
-27,
60
]
]
}
]
}
]Returns the list of realms with details about the users in it
List of the current state of the realms. The userParcels array is the list of parcels in which there are users present.
GET /lambdas/explore/realms HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
List of the current state of the realms. The userParcels array is the list of parcels in which there are users present.
[
{
"serverName": "loki",
"url": "https://interconnected.online",
"layer": "blue",
"usersCount": 66,
"maxUsers": 100,
"userParcels": [
[
-27,
58
]
]
},
{
"serverName": "fenrir",
"url": "https://peer.decentraland.org",
"layer": "amber",
"usersCount": 61,
"maxUsers": 100,
"userParcels": [
[
-68,
60
],
[
11,
139
]
]
}
]Get the operators for a parcel
X coordinate of the parcel
100Y coordinate of the parcel
100operators for a parcel
Bad request
GET /lambdas/parcels/{x}/{y}/operators HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
{
"address": "0xddf1eec586d8f8f0eb8c5a3bf51fb99379a55123",
"operator": "0xddf1eec586d8f8f0eb8c5a3bf51fb99379a55684",
"updateOperator": "0xddf1eec586d8f8f0eb8c5a3bf51fb99379a55684",
"updateManagers": [
"0xddf1eec586d8f8f0eb8c5a3bf51fb99379a55684"
],
"approvedForAll": [
"0xddf1eec586d8f8f0eb8c5a3bf51fb99379a55684"
]
}Returns all the Avatars details associated with the Ethereum addresses in the body
Array of Avatars
No profile was modified since If-Modified-Since header
POST /lambdas/profiles HTTP/1.1
Host: peer.decentraland.zone
Content-Type: application/json; charset=utf-8
Accept: */*
Content-Length: 99
{
"ids": [
"0x5e5d9d1dfd87e9b8b069b8e5d708db92be5ade99",
"0x22480812a9a0669783c06d359182a583bd1d9fc2"
]
}[
{
"timestamp": 1732684800,
"avatars": [
{
"userId": "0x5e5d9d1dfd87e9b8b069b8e5d708db92be5ade99",
"email": "",
"name": "Paralax24#de99",
"hasClaimedName": false,
"description": "",
"ethAddress": "0x5e5D9D1dfD87E9B8B069B8e5d708dB92bE5ADe99",
"version": 2,
"avatar": {
"bodyShape": "urn:decentraland:off-chain:base-avatars:BaseMale",
"snapshots": {
"face": "https://peer.decentraland.org/content/contents/QmcYhp7gvmq8eLiLEUs9MbYFkAekaMfM23Y8YPhWGP7nYq",
"face128": "https://peer.decentraland.org/content/contents/Qmc9FCM3HMGQpMbvyvkP6WweDGSxTL9Gxoyfsg6eAe8fyY",
"face256": "https://peer.decentraland.org/content/contents/QmUKJme83AmeaKg6adRZQFDPkBSKbafRXwgCjL7vfHsoJJ",
"body": "https://peer.decentraland.org/content/contents/QmY9Zoqg3Fngi9d3ALnt7PdLXVS8RrgcEaTsz9eBnCnvUB"
},
"eyes": {
"color": {
"r": 0.22265625,
"g": 0.484375,
"b": 0.69140625
}
},
"hair": {
"color": {
"r": 0.98046875,
"g": 0.82421875,
"b": 0.5078125
}
},
"skin": {
"color": {
"r": 0.94921875,
"g": 0.76171875,
"b": 0.6484375
}
},
"wearables": [
"urn:decentraland:off-chain:base-avatars:eyebrows_00",
"urn:decentraland:off-chain:base-avatars:eyes_06",
"urn:decentraland:off-chain:base-avatars:mouth_03",
"urn:decentraland:off-chain:base-avatars:casual_hair_03",
"urn:decentraland:off-chain:base-avatars:oxford_pants",
"urn:decentraland:off-chain:base-avatars:black_jacket",
"urn:decentraland:off-chain:base-avatars:m_feet_soccershoes",
"urn:decentraland:off-chain:base-avatars:italian_director",
"urn:decentraland:off-chain:base-avatars:lincoln_beard"
]
},
"tutorialStep": 256,
"interests": [],
"unclaimedName": "Paralax24"
}
]
},
{
"timestamp": 1732684801,
"avatars": [
{
"userId": "0x22480812a9a0669783c06d359182a583bd1d9fc2",
"email": "",
"name": "cestfini#9fc2",
"hasClaimedName": false,
"description": "",
"ethAddress": "0x22480812a9a0669783c06d359182a583bd1d9fc2",
"version": 2,
"avatar": {
"bodyShape": "urn:decentraland:off-chain:base-avatars:BaseMale",
"snapshots": {
"face": "https://peer.decentraland.org/content/contents/QmeBEgsxrxTAEs9kFxgwyfJN8vUtqw8WJ4bthwhti3S9aL",
"face128": "https://peer.decentraland.org/content/contents/QmVGRZxYmWL6z6JhkQtzo1KkWqdeZfxt6gzuCPY6nvbmhb",
"face256": "https://peer.decentraland.org/content/contents/Qma7zpPZkwFDyCe1gj62nBYsYTmD2ZSSvxcQXZDmR1FTnC",
"body": "https://peer.decentraland.org/content/contents/QmeqDMMK3KYSzuboKnPPtjG94bHCYtfCmHEeYRhpSBRuhn"
},
"eyes": {
"color": {
"r": 0.37109375,
"g": 0.22265625,
"b": 0.1953125
}
},
"hair": {
"color": {
"r": 0.234375,
"g": 0.12890625,
"b": 0.04296875
}
},
"skin": {
"color": {
"r": 0.94921875,
"g": 0.76171875,
"b": 0.6484375
}
},
"wearables": [
"urn:decentraland:off-chain:base-avatars:hair_coolshortstyle",
"urn:decentraland:off-chain:base-avatars:eyebrows_05",
"urn:decentraland:off-chain:base-avatars:eyes_08",
"urn:decentraland:off-chain:base-avatars:mouth_01",
"urn:decentraland:off-chain:base-avatars:full_beard",
"urn:decentraland:off-chain:base-avatars:red_square_shirt",
"urn:decentraland:off-chain:base-avatars:hip_hop_joggers",
"urn:decentraland:off-chain:base-avatars:m_mountainshoes.glb",
"urn:decentraland:off-chain:base-avatars:thug_life"
]
},
"tutorialStep": 384,
"interests": [],
"unclaimedName": "cestfini"
}
]
}
]Given a Ethereum address of a user, return the Avatars details associated with it.
Ethereum address of the user
0x22480812a9a0669783c06d359182a583bd1d9fc2Array of Avatars
GET /lambdas/profiles/{id} HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
Array of Avatars
{
"timestamp": 1732684800,
"avatars": [
{
"userId": "0x22480812a9a0669783c06d359182a583bd1d9fc2",
"email": "",
"name": "cestfini#9fc2",
"hasClaimedName": false,
"description": "",
"ethAddress": "0x22480812a9a0669783c06d359182a583bd1d9fc2",
"version": 2,
"avatar": {
"bodyShape": "urn:decentraland:off-chain:base-avatars:BaseMale",
"snapshots": {
"face": "https://peer.decentraland.org/content/contents/QmeBEgsxrxTAEs9kFxgwyfJN8vUtqw8WJ4bthwhti3S9aL",
"face128": "https://peer.decentraland.org/content/contents/QmVGRZxYmWL6z6JhkQtzo1KkWqdeZfxt6gzuCPY6nvbmhb",
"face256": "https://peer.decentraland.org/content/contents/Qma7zpPZkwFDyCe1gj62nBYsYTmD2ZSSvxcQXZDmR1FTnC",
"body": "https://peer.decentraland.org/content/contents/QmeqDMMK3KYSzuboKnPPtjG94bHCYtfCmHEeYRhpSBRuhn"
},
"eyes": {
"color": {
"r": 0.37109375,
"g": 0.22265625,
"b": 0.1953125
}
},
"hair": {
"color": {
"r": 0.234375,
"g": 0.12890625,
"b": 0.04296875
}
},
"skin": {
"color": {
"r": 0.94921875,
"g": 0.76171875,
"b": 0.6484375
}
},
"wearables": [
"urn:decentraland:off-chain:base-avatars:hair_coolshortstyle",
"urn:decentraland:off-chain:base-avatars:eyebrows_05",
"urn:decentraland:off-chain:base-avatars:eyes_08",
"urn:decentraland:off-chain:base-avatars:mouth_01",
"urn:decentraland:off-chain:base-avatars:full_beard",
"urn:decentraland:off-chain:base-avatars:red_square_shirt",
"urn:decentraland:off-chain:base-avatars:hip_hop_joggers",
"urn:decentraland:off-chain:base-avatars:m_mountainshoes.glb",
"urn:decentraland:off-chain:base-avatars:thug_life"
]
},
"tutorialStep": 384,
"interests": [],
"unclaimedName": "cestfini"
}
]
}Given a Ethereum address of a user, return the Outfits entity.
Ethereum address of the user
0x22480812a9a0669783c06d359182a583bd1d9fc2Outfits entity
GET /lambdas/outfits/{id} HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
Outfits entity
[
{
"version": "v3",
"id": "QmQ9UorFsVTpaVpCwJZAzFyCmaGf7Ksi6aQHYTJVKyzVMh",
"type": "outfits",
"timestamp": 1581034082829,
"pointers": [
"0xa87d168717538e86d71ac48baccaeb84162de602:outfits"
],
"content": [],
"metadata": {
"outfits": [
{
"slot": 1,
"outfit": {
"bodyShape": "urn:decentraland:off-chain:base-avatars:BaseMale",
"eyes": {
"color": {
"r": 0.23046875,
"g": 0.625,
"b": 0.3125
}
},
"hair": {
"color": {
"r": 0.35546875,
"g": 0.19140625,
"b": 0.05859375
}
},
"skin": {
"color": {
"r": 0.94921875,
"g": 0.76171875,
"b": 0.6484375
}
},
"wearables": [
"urn:decentraland:matic:collections-v2: 0xf6f601efee04e74cecac02c8c5bdc8cc0fc1c721:0",
"urn:decentraland:matic:collections-v2: 0x04e7f74e73e951c61edd80910e46c3fece5ebe80:2",
"urn:decentraland:ethereum:collections-v1:rtfkt_x_atari:p_rtfkt_x_atari_feet"
]
}
},
{
"slot": 5,
"outfit": {
"bodyShape": "urn:decentraland:off-chain:base-avatars:BaseMale",
"eyes": {
"color": {
"r": 0.23046875,
"g": 0.625,
"b": 0.3125
}
},
"hair": {
"color": {
"r": 0.35546875,
"g": 0.19140625,
"b": 0.05859375
}
},
"skin": {
"color": {
"r": 0.94921875,
"g": 0.76171875,
"b": 0.6484375
}
},
"wearables": [
"urn:decentraland:matic:collections-v2: 0xf6f601efee04e74cecac02c8c5bdc8cc0fc1c721:0",
"urn:decentraland:matic:collections-v2: 0x04e7f74e73e951c61edd80910e46c3fece5ebe80:2",
"urn:decentraland:ethereum:collections-v1:rtfkt_x_atari:p_rtfkt_x_atari_feet"
]
}
}
],
"namesForExtraSlots": [
"perro"
]
}
}
]Returns the list of third party integrations as well as collections
Returns the list of third party integrations and collections
Returns the list of third party integrations and collections
GET /lambdas/third-party-integrations HTTP/1.1
Host: peer.decentraland.zone
Accept: */*
Returns the list of third party integrations and collections
{
"data": [
{
"urn": "urn:decentraland:ethereum:ext:cryptopunks:0xContractAddressaaabbff999123",
"name": "Jean Pier",
"description": "Crypto punks (third party)"
},
{
"urn": "urn:decentraland:matic:collections-v1:halloween",
"name": "Halloween hat",
"description": "Decentraland Halloween 2019"
},
{
"urn": "urn:decentraland:matic:collections-v2:halloween",
"name": "Halloween tshirt",
"description": "Decentraland Halloween 2020"
}
]
}Last updated